<?php
// #######################################################
// Author: Markus Widmer & Martin Haase, DAASI International GmbH
// Creation date: 17.07.2007
// Modification date: 15.10.2010
// Version: 0.3.0
// #######################################################

class TgExtraCrud {

  // Global variables
  protected $rbac;
  protected $config;
  protected $connection;

  // -----------------------------------------------------
  // Constructor
  // Input: none
  // Output: object RBACcore
  // Description:
  //   Creates initial connections to the LDAP-server and
  //   sets some configuration parameters.
  // -----------------------------------------------------
  public function __construct( $inConfigurationFilename, $inRbacConfFile, $inRbacBase ) {

    $this->rbac = new RBAC( $inRbacConfFile, $inRbacBase );


    $this->config = new SimpleConfig( $inConfigurationFilename );


    // Create connection
    $this->connection['user'] = new LDAP();
    $this->connection['user']->connect( $this->config->getValue( "authentication", "host" ),
                                        $this->config->getValue( "authentication", "port" ),
                                        $this->config->getValue( "authentication", "version" ),
                                        preg_match( "/yes/i", $this->config->getValue( "authentication", "tls" ) ) ? true : false );
    $this->connection['user']->bind( $this->config->getValue( "authentication", "binddn" ),
                                     $this->config->getValue( "authentication", "password" ) );


    $this->connection['counter'] = new LDAP();
    $this->connection['counter']->connect( $this->config->getValue( "counter", "host" ),
                                           $this->config->getValue( "counter", "port" ),
                                           $this->config->getValue( "counter", "version" ),
                                           preg_match( "/yes/i", $this->config->getValue( "counter", "tls" ) ) ? true : false );
    $this->connection['counter']->bind( $this->config->getValue( "counter", "binddn" ),
                                        $this->config->getValue( "counter", "password" ) );


    $this->connection['resource'] = $this->rbac->getConnection( "resource" );
    $this->connection['role'] = $this->rbac->getConnection( "role" );
    $this->connection['session'] = $this->rbac->getConnection( "session" );

  }




  // -----------------------------------------------------
  // Function: nearlyPublish
  // Input: auth / xsd:string
  //        log / xsd:string
  //        project / xsd:string
  // Output: result / xsd:boolean
  // Description
  //   Returns a list of operations allowed by the user
  //   on a specific resource.
  // -----------------------------------------------------
  public function nearlyPublish( $inRequest ) {

    $arrResource = Array();
    $arrModify = Array();
    $filter = "";
    $result = new booleanResponse();  // The return-result
    $objFaultDetail = new stdClass();


    $filter  = "(&" . $this->rbac->getConfiguration()->getValue( "resource", "filter" );
    $filter .= "(|(" . $this->rbac->getConfiguration()->getValue( "resource", "namingattribute" ) . "=" . $inRequest->resource . ")";
    $filter .= "  (" . $this->rbac->getConfiguration()->getValue( "resource", "aliasattribute" ) . "=" . $inRequest->resource . ")))";


    // Get the resource
    $arrResource = $this->connection['resource']->search( $this->rbac->getConfiguration()->getValue( "resource", "base" ), $filter, "sub",
                                                          Array( "rbacpermission", "tgispublic", "tgprojectid" ) );


    if( $this->rbac->checkAccess( $inRequest->auth, "publish", $inRequest->resource ) ) {

      $file = fopen( "/tmp/debug.log", "a+" );
      fwrite( $file, "Resource: " . serialize( $arrResource ) . "\n" );
      fclose( $file );
      $arrModify['rbacpermission'] = Array();


      for( $loPermission = 0; $loPermission < sizeof( $arrResource[0]['rbacpermission'] ); $loPermission++ ) {

        $file = fopen( "/tmp/debug.log", "a+" );
        fwrite( $file, "Permission: " . serialize( $arrResource[0]['rbacpermission'][$loPermission] ) . "\n" );
        fclose( $file );
        if(    preg_match( "/:-:publish$/i", $arrResource[0]['rbacpermission'][$loPermission] )
            || preg_match( "/:-:delete$/i", $arrResource[0]['rbacpermission'][$loPermission] ) ) {

          $arrModify['rbacpermission'][] = $arrResource[0]['rbacpermission'][$loPermission];

        } 

      }


      $arrModify['tgispublic'][] = "TRUE";
      $result->result = $this->connection['resource']->modify( $arrResource[0]['dn'], $arrModify );

    }
    else {

      $objFaultDetail->faultNo = $this->config->getValue( "errorCode", "INSUFFICIENT_ACCESS" );
      $objFaultDetail->faultMessage = $this->config->getValue( "errorDescription", "INSUFFICIENT_ACCESS" );
      $objFaultDetail->cause = "You do not have the permission publish the resource " . $inRequest->resource . ".";


      return new SoapFault( "authenticationFault",
                             $this->config->getValue( "errorCode", "INSUFFICIENT_ACCESS" ),
                             get_class( $this ),
                             $objFaultDetail );

    }


    return $result;

  }

}
?>
